@@ -12,7 +12,9 @@ class CloudFoundryApp(object):
     state = ""
     uris = []
 
-    def __init__(self, name, env=None, instances=None, meta=None, created=None, debug=None, version=None, runningInstances=None, services=None, state=None, uris=None, staging=None, resources=None):
+    def __init__(self, name, env=None, instances=None, meta=None, created=None, debug=None, version=None,
+                 runningInstances=None, services=None, state=None, uris=None, staging=None, resources=None,
+                 interface=None):
         self.name = name
         self.environment_variables = env
         self.instances = instances
@@ -24,7 +26,13 @@ class CloudFoundryApp(object):
         self.services = services
         self.state = state
         self.uris = uris
+        self.interface = interface
 
     @staticmethod
-    def from_dict(dict):
-        return CloudFoundryApp(**dict)
\ No newline at end of file
+    def from_dict(dict, interface=None):
+        return CloudFoundryApp(interface=interface, **dict)
+
+    def delete(self):
+        if not self.interface:
+            raise Exception("Tried to delete app %s without providing an interface for doing so" % self.name)
+        self.interface.delete_app(self.name)
\ No newline at end of file
